########## R-function: BRugsMCMC ##########

# Custom-made variant of BRugsFit() that, for example,
# provides progress reports.

# Last changed: 25 JUN 2008

BRugsMCMC <- function(data,inits,parametersToSave,nBurnin,nIter,nThin=1,modelFile)
{
   par(mfrow=c(1,1))
   if ((nBurnin<100)|(nIter<100))
      stop("currently only working for chains longer than 100")

   if ((100*round(nBurnin/100)!=nBurnin)|(100*round(nIter/100)!=nIter))
      warning("chain lengths not multiples of 100; truncation may occur.")

   blankPlot <- function()
      plot(0,0,type="n",xlim=c(0,1),ylim=c(0,1),xaxt ="n",yaxt="n",
           xlab="",ylab="",bty="n")

   blankPlot()
   text(0.5,0.5,"WELCOME TO BRugsMCMC()!",cex=2,col="navy")
   modelCheck(modelFile)
   blankPlot()
   text(0.5,0.5,"Model checked.",cex=2,col="DeepPink")
   modelData(bugsData(data))
   blankPlot()
   text(0.5,0.5,"Data read in.",cex=2,col="dodgerblue")
   modelCompile(numChains=1)
   blankPlot()
   text(0.5,0.5,"Compilation completed.",cex=2,col="DarkOrange")
   modelInits(bugsInits(inits))
   blankPlot()
   text(0.5,0.7,"Initialisation completed.",cex=2,col="green3")
   text(0.5,0.3,"Burnin commencing.......",cex=2,col="green3")

   # Do burn-in

   burninIncSize <- round(nBurnin/(nThin*100))     
   for (i in 1:100)
   {
      modelUpdate(burninIncSize,thin=nThin)
      blankPlot()
      text(0.5,0.7,"Percentage of burnin completed is",cex=1,col="red")
      text(0.5,0.2,i,cex=7,col="red")

   }      

   samplesSet(parametersToSave)

   # Do iterations

   iterIncSize <- round(nIter/(nThin*100))     
   for (i in 1:100)
   {
      modelUpdate(iterIncSize,thin=nThin)
      blankPlot()
      text(0.5,0.7,"Percentage of iterations completed is",cex=1,col="blue")
      text(0.5,0.2,i,cex=7,col="blue")
   }      
 
   sims <- samplesStats("*")
   return(list(Stats=sims))
}

########## End of BRugsMCMC ##########
